from pobaidu.api import imageprocess
from pobaidu.api import face
from pobaidu.lib.Const import SPLIT_LINE

print(SPLIT_LINE)
print('【pobaidu库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、请+【项目交流群】：http://t.cn/A65MiFvH')
print('2、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/pobaidu')
print(SPLIT_LINE)
